<?php 
/**
 * @package  copilotPlugin
 */
namespace Inc\Pages;

use Inc\Api\SettingsApi;
use Inc\Base\BaseController;
use Inc\Api\Callbacks\AdminCallbacks;

/**
* 
*/
class Admin extends BaseController
{
	public $settings;
	public $callbacks;
	public $pages = array();
	public $subpages = array();

	public function register() 
	{
		$this->settings = new SettingsApi();
		$this->callbacks = new AdminCallbacks();
		$this->setPages();
		$this->setSubpages();
		$this->setSettings();
		$this->setSections();
		$this->setFields();
		$this->settings->addPages( $this->pages )->withSubPage( 'Info' )->addSubPages( $this->subpages )->register();
	}

	public function setPages() 
	{
		$this->pages = array(
			array(
				'page_title' => 'copilot Plugin', 
				'menu_title' => 'copilot', 
				'capability' => 'manage_options', 
				'menu_slug' => 'copilot_plugin', 
				'callback' => array( $this->callbacks, 'adminTemplates' ), 
				'icon_url' => 'dashicons-star-filled', 
				'position' => 110
			)
		);
	}

	public function setSubpages()
	{
		$this->subpages = array(
			array(
				'parent_slug' => 'copilot_plugin', 
				'page_title' => 'Settings', 
				'menu_title' => 'Einstellungen', 
				'capability' => 'manage_options', 
				'menu_slug' => 'copilot_settings', 
				'callback' => array( $this->callbacks, 'adminSettings' )
			),
			array(
				'parent_slug' => 'copilot_plugin', 
				'page_title' => 'API Call', 
				'menu_title' => 'API Call', 
				'capability' => 'manage_options', 
				'menu_slug' => 'copilot_api_call', 
				'callback' => array( $this->callbacks, 'adminApiCall' )
			)
		);
	}

	public function setSettings()
	{
		$args = array(
			array(
				'option_group' => 'copilot_settings_options_group',
				'option_name' => 'api_url',
				'callback' => array( $this->callbacks, 'copilotSettingsOptionsGroup' )
			),
			array(
				'option_group' => 'copilot_settings_options_group',
				'option_name' => 'api_token',
				'callback' => array( $this->callbacks, 'copilotSettingsOptionsGroup' )
			)
		);

		$this->settings->setSettings( $args );
	}

	public function setSections()
	{
		$args = array(
			array(
				'id' => 'copilot_settings',
				'title' => '',
				'callback' => array( $this->callbacks, 'copilotSettingsSection' ),
				'page' => 'copilot_settings'
			),
			array(
				'id' => 'copilot_api_call',
				'title' => '',
				'callback' => array( $this->callbacks, 'copilotHelpSection' ),
				'page' => 'copilot_api_call'
			)
		);

		$this->settings->setSections( $args );
	}

	public function setFields()
	{
		$args = array(
			array(
				'id' => 'api_url',
				'title' => 'API URL',
				'callback' => array( $this->callbacks, 'copilotApiPath' ),
				'page' => 'copilot_settings',
				'section' => 'copilot_settings',
				'args' => array(
					'label_for' => 'api_url',
					'class' => 'example-class'
				)
			)
			,array(
				'id' => 'api_token',
				'title' => 'API Token',
				'callback' => array( $this->callbacks, 'copilotApiToken' ),
				'page' => 'copilot_settings',
				'section' => 'copilot_settings',
				'args' => array(
					'label_for' => 'api_token',
					'class' => 'example-class'
				)
			)
		);

		$this->settings->setFields( $args );
	}
}