<?php 
/**
 * @package  copilotPlugin
 */
namespace Inc\Pages;
use Inc\Api\Callbacks\AdminCallbacks;
use Handlebars\Handlebars;
use Handlebars\Loader\FilesystemLoader;

/**
* 
*/
class Output 
{
	public $callbacks;
	public $handlebars;
	
	function __construct()
	{
		$this->callbacks = new AdminCallbacks();
		# Set the partials files
		$partialsDir = dirname(__FILE__).'/../../views';
		$partialsLoader = new FilesystemLoader($partialsDir,
			[
				"extension" => "html"
			]
		);

		# We'll use $handlebars throughout this the examples, assuming the will be all set this way
		$this->handlebars = new Handlebars([
			"loader" => $partialsLoader,
			"partials_loader" => $partialsLoader
		]);

		$this->handlebars->addHelper("getValueFromSchedules",
			function($template, $context, $args, $source){
				$ValueByKey = "";
				preg_match("/'(.*?)'/", $args, $m);

				if(isset($m[1])){
					if(
						!is_null($context->get("schedule")) && 
						is_array($context->get("schedule")) && 
						count($context->get("schedule")) > 0
					){ 
						foreach($context->get("schedule") as $value){
							if($value["name"] === $m[1]){
								$ValueByKey = $value["date"];
								break;
							}
						}
						if($ValueByKey){
							$ValueByKey = new \DateTime($value["date"]);
							return $ValueByKey->format("H:i");
						} else return "";
					} else return "";
				} else {
					return "Bitte Argument mit einfachen Anführungsstrichen angeben";
				}
			}
		);

		$this->handlebars->addHelper("getValueFromEventInformation",
			function($template, $context, $args, $source){
				$ValueByKey = "";
				preg_match("/'(.*?)'/", $args, $m);

				if(isset($m[1])){
					if(
						!is_null($context->get("eventInformations")) && 
						is_array($context->get("eventInformations")) && 
						count($context->get("eventInformations")) > 0
					){ 
						foreach($context->get("eventInformations") as $value){
							if($value["name"] == $m[1]){
								$ValueByKey = $value["value"];
								break;
							}
						}
						return $ValueByKey;
					} else return "";
				} else {
					return "Bitte Argument mit einfachen Anführungsstrichen angeben";
				}
			}
		);

	}
	
	public function copilotOutput($atts = [])
	{
		if(isset($atts["id"])){
			return $this->singleEvent($atts['id']);
		} else if(isset($atts["promotiontype"])){
			return $this->eventsList($atts['promotiontype']);
		} else if (isset( $_GET['id'])){
			return $this->singleEvent($_GET['id']);
		} else {
			return $this->eventsList();
		}
	} 

	function eventsList($promotiontype = "")
	{
		$events = $this->callbacks->copilotApiCall("events", $promotiontype);
		return $this->handlebars->render("eventsList", $events["data"]);
	} 

	function singleEvent($id)
	{
		$event = $this->callbacks->copilotApiCall("event/".$id);
		return $this->handlebars->render("singleEvent", $event);
	} 
}